@@ -44,7 +44,7 @@ import Development.Shake.FilePath
 import Development.Shake.FilePattern
 import Development.Shake.Types
 import Development.Shake.Rules.File
-import Development.Shake.Derived(writeFile', withTempDir)
+import Development.Shake.Derived
 
 ---------------------------------------------------------------------
 -- ACTUAL EXECUTION
@@ -144,9 +144,36 @@ commandExplicit funcName oopts results exe args = do
                                          , not $ any ($ x) ignore]
 
         fsaCmd act opts file
+            | isMac = fsaCmdMac act opts file
             | useShell = runShell (unwords $ exe : args) $ \exe args -> act "fsatrace" $ opts : file : "--" : exe : args
             | otherwise = act "fsatrace" $ opts : file : "--" : exe : args
 
+        fsaCmdMac act opts file = do
+            let fakeExe e = liftIO $ do
+                    me <- findExecutable e
+                    case me of
+                        Just re -> do
+                            let isSystem = any (`isPrefixOf` re) [ "/bin"
+                                                                 , "/usr"
+                                                                 , "/sbin"
+                                                                 ]
+                            if isSystem
+                                then do
+                                    tmpdir <- getTemporaryDirectory
+                                    let fake = tmpdir ++ "fsatrace-fakes" ++ re
+                                    unlessM (doesFileExist fake) $ do
+                                        createDirectoryIfMissing True $ takeDirectory fake
+                                        copyFile re fake
+                                    return fake
+                                else return re
+                        Nothing -> return e
+            fexe <- fakeExe exe
+            if useShell
+                then do
+                    fsh <- fakeExe "/bin/sh"
+                    act "fsatrace" $ opts : file : "--" : fsh : "-c" : [unwords $ fexe : args]
+                else act "fsatrace" $ opts : file : "--" : fexe : args
+
         fsatrace act = withTempFile $ \file -> do
             res <- fsaCmd act "rwm" file
             xs <- liftIO $ parseFSAT <$> readFileUTF8' file
@@ -383,6 +410,7 @@ newtype CmdTime = CmdTime {fromCmdTime :: Double}
 --   suitable for user diagnostics, but not for direct execution.
 newtype CmdLine = CmdLine {fromCmdLine :: String}
 
+-- | The allowable 'String'-like values that can be captured.
 class CmdString a where cmdString :: (Str, Str -> a)
 instance CmdString () where cmdString = (Unit, \Unit -> ())
 instance CmdString String where cmdString = (Str "", \(Str x) -> x)
@@ -533,6 +561,7 @@ type a :-> t = a
 cmd :: CmdArguments args => args :-> Action r
 cmd = cmdArguments []
 
+-- | The arguments to 'cmd' - see 'cmd' for examples and semantics.
 class CmdArguments t where cmdArguments :: [Either CmdOption String] -> t
 instance (Arg a, CmdArguments r) => CmdArguments (a -> r) where
     cmdArguments xs x = cmdArguments $ xs ++ arg x
@@ -560,12 +589,6 @@ instance Arg a => Arg (Maybe a) where arg = maybe [] arg
 ---------------------------------------------------------------------
 -- UTILITIES
 
--- Copied from Derived. Once Derived no longer exports cmd stuff, import from there.
-withTempFile :: (FilePath -> Action a) -> Action a
-withTempFile act = do
-    (file, del) <- liftIO newTempFile
-    act file `actionFinally` del
-
 -- A better version of showCommandForUser, which doesn't escape so much on Windows
 showCommandForUser2 :: FilePath -> [String] -> String
 showCommandForUser2 cmd args = unwords $ map (\x -> if safe x then x else showCommandForUser x []) $ cmd : args
