@@ -13,7 +13,7 @@ import Development.Shake.Classes
 
 ---------------------------------------------------------------------
 -- Data.ByteString
--- Mostly because ByteString does not have an NFData instance in older GHC
+-- Mostly because ByteString does not have an NFData instance in GHC 7.4
 
 -- | ASCII ByteString
 newtype BS = BS BS.ByteString
@@ -35,6 +35,8 @@ newtype BSU = BSU BS.ByteString
 instance NFData BSU where
     rnf (BSU x) = x `seq` ()
 
+instance Show BSU where
+    show = unpackU
 
 
 pack :: String -> BS
